@@ -37,6 +37,7 @@ ArchiveManager::~ArchiveManager()
 
 ArchiveManager *ArchiveManager::get_instance()
 {
+    // qDebug() << "get_instance called";
 #ifndef Q_ATOMIC_POINTER_TEST_AND_SET_IS_SOMETIMES_NATIVE
     if (!QAtomicPointer<ArchiveManager>::isTestAndSetNative()) //运行时检测
         qInfo() << "Error: TestAndSetNative not supported!";
@@ -48,6 +49,7 @@ ArchiveManager *ArchiveManager::get_instance()
      * 不会被重新排序。
      */
     if (m_instance.testAndSetOrdered(nullptr, nullptr)) { //第一次检测
+        qDebug() << "Creating new ArchiveManager instance";
         QMutexLocker locker(&m_mutex);//加互斥锁。
 
         m_instance.testAndSetOrdered(nullptr, new ArchiveManager);//第二次检测。
@@ -58,6 +60,7 @@ ArchiveManager *ArchiveManager::get_instance()
 
 void ArchiveManager::destory_instance()
 {
+    qDebug() << "destroy_instance called";
     SAFE_DELETE_ELE(m_instance)
 }
 
@@ -74,9 +77,11 @@ bool ArchiveManager::createArchive(const QList<FileEntry> &files, const QString
         qWarning() << "Path control check failed for destination:" << strDestination;
         return false;
     }
+    qDebug() << "Creating interface for destination";
     m_pTempInterface = UiTools::createInterface(strDestination, true, eType);
 
     if (m_pTempInterface) {
+        qDebug() << "Creating CreateJob";
         CreateJob *pCreateJob = new CreateJob(files, m_pTempInterface, stOptions, this);
 
         // 连接槽函数
@@ -111,9 +116,11 @@ bool ArchiveManager::loadArchive(const QString &strArchiveFullPath, UiTools::Ass
         m_pInterface = nullptr;
     }
 
+    qDebug() << "Creating interface for loading";
     m_pInterface = UiTools::createInterface(strArchiveFullPath, false, eType);
 
     if (m_pInterface) {
+        qDebug() << "Creating LoadJob";
         LoadJob *pLoadJob = new LoadJob(m_pInterface);
 
         // 连接槽函数
@@ -133,15 +140,18 @@ bool ArchiveManager::loadArchive(const QString &strArchiveFullPath, UiTools::Ass
 
 bool ArchiveManager::addFiles(const QString &strArchiveFullPath, const QList<FileEntry> &listAddEntry, const CompressOptions &stOptions)
 {
+    qDebug() << "Starting addFiles operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::AddCompressFile},
         {"operate", "AddCompressFile"},
         {"describe", QString("Add File to package: ") + strArchiveFullPath}
     };
     EventLogUtils::get().writeLogs(obj);
+    qDebug() << "Creating interface for adding files";
     m_pTempInterface = UiTools::createInterface(strArchiveFullPath, true);
 
     if (m_pTempInterface) {
+        qDebug() << "Creating AddJob";
         AddJob *pAddJob = new AddJob(listAddEntry, m_pTempInterface, stOptions);
 
         // 连接槽函数
@@ -153,14 +163,17 @@ bool ArchiveManager::addFiles(const QString &strArchiveFullPath, const QList<Fil
         m_pArchiveJob = pAddJob;
         pAddJob->start();
 
+        qDebug() << "AddJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for adding files";
     return false;
 }
 
 bool ArchiveManager::extractFiles(const QString &strArchiveFullPath, const QList<FileEntry> &files, const ExtractionOptions &stOptions, UiTools::AssignPluginType eType)
 {
+    qDebug() << "Starting extractFiles operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::ExtractCompressFile},
         {"operate", "ExtractCompressFile"},
@@ -168,11 +181,13 @@ bool ArchiveManager::extractFiles(const QString &strArchiveFullPath, const QList
     };
     EventLogUtils::get().writeLogs(obj);
     if (nullptr == m_pInterface) {
+        qDebug() << "Creating interface for extraction";
         m_pInterface = UiTools::createInterface(strArchiveFullPath, false, eType);
     }
 
     if (m_pInterface) {
         if (!stOptions.bTar_7z) {
+            qDebug() << "Creating ExtractJob for regular extraction";
             ExtractJob *pExtractJob = new ExtractJob(files, m_pInterface, stOptions);
 
             // 连接槽函数
@@ -187,6 +202,7 @@ bool ArchiveManager::extractFiles(const QString &strArchiveFullPath, const QList
 
             return pExtractJob->errorcode;
         } else {
+            qDebug() << "Creating StepExtractJob for tar.7z archive";
             // tar.7z包使用分步解压流程
             StepExtractJob *pStepExtractJob = new StepExtractJob(strArchiveFullPath, stOptions/*, strTargetFullPath, strNewArchiveFullPath*/);
             m_pArchiveJob = pStepExtractJob;
@@ -198,10 +214,12 @@ bool ArchiveManager::extractFiles(const QString &strArchiveFullPath, const QList
             connect(pStepExtractJob, &StepExtractJob::signalQuery, this, &ArchiveManager::signalQuery);
 
             pStepExtractJob->start();
+            qDebug() << "StepExtractJob started successfully";
             return true;
         }
     }
 
+    qWarning() << "Failed to create interface for extraction";
     // 发送结束信号
     emit signalJobFinished(ArchiveJob::JT_Extract, PFT_Error, ET_PluginError);
     return false;
@@ -209,6 +227,7 @@ bool ArchiveManager::extractFiles(const QString &strArchiveFullPath, const QList
 
 bool ArchiveManager::extractFiles2Path(const QString &strArchiveFullPath, const QList<FileEntry> &listSelEntry, const ExtractionOptions &stOptions)
 {
+    qDebug() << "Starting extractFiles2Path operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::ExtractSingleFile},
         {"operate", "ExtractSingleFile"},
@@ -216,10 +235,12 @@ bool ArchiveManager::extractFiles2Path(const QString &strArchiveFullPath, const
     };
     EventLogUtils::get().writeLogs(obj);
     if (nullptr == m_pInterface) {
+        qDebug() << "Creating interface for extraction to path";
         m_pInterface = UiTools::createInterface(strArchiveFullPath);
     }
 
     if (m_pInterface) {
+        qDebug() << "Creating ExtractJob for extraction to path";
         ExtractJob *pExtractJob = new ExtractJob(listSelEntry, m_pInterface, stOptions);
 
         // 连接槽函数
@@ -231,14 +252,17 @@ bool ArchiveManager::extractFiles2Path(const QString &strArchiveFullPath, const
         m_pArchiveJob = pExtractJob;
         pExtractJob->start();
 
+        qDebug() << "ExtractJob for extraction to path started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for extraction to path";
     return false;
 }
 
 bool ArchiveManager::deleteFiles(const QString &strArchiveFullPath, const QList<FileEntry> &listSelEntry)
 {
+    qDebug() << "Starting deleteFiles operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::DelCompressFile},
         {"operate", "DelCompressFile"},
@@ -246,10 +270,12 @@ bool ArchiveManager::deleteFiles(const QString &strArchiveFullPath, const QList<
     };
     EventLogUtils::get().writeLogs(obj);
     if (nullptr == m_pInterface) {
+        qDebug() << "Creating interface for deletion";
         m_pInterface = UiTools::createInterface(strArchiveFullPath);
     }
 
     if (m_pInterface) {
+        qDebug() << "Creating DeleteJob";
         DeleteJob *pDeleteJob = new DeleteJob(listSelEntry, m_pInterface);
 
         // 连接槽函数
@@ -261,14 +287,17 @@ bool ArchiveManager::deleteFiles(const QString &strArchiveFullPath, const QList<
         m_pArchiveJob = pDeleteJob;
         pDeleteJob->start();
 
+        qDebug() << "DeleteJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for deletion";
     return false;
 }
 
 bool ArchiveManager::renameFiles(const QString &strArchiveFullPath, const QList<FileEntry> &listSelEntry)
 {
+    qDebug() << "Starting renameFiles operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::RenameCompressFile},
         {"operate", "RenameCompressFile"},
@@ -276,10 +305,12 @@ bool ArchiveManager::renameFiles(const QString &strArchiveFullPath, const QList<
     };
     EventLogUtils::get().writeLogs(obj);
     if (nullptr == m_pInterface) {
+        qDebug() << "Creating interface for renaming";
         m_pInterface = UiTools::createInterface(strArchiveFullPath);
     }
 
     if (m_pInterface) {
+        qDebug() << "Creating RenameJob";
         RenameJob *pRenameJob = new RenameJob(listSelEntry, m_pInterface);
 
         // 连接槽函数
@@ -291,18 +322,22 @@ bool ArchiveManager::renameFiles(const QString &strArchiveFullPath, const QList<
         m_pArchiveJob = pRenameJob;
         pRenameJob->start();
 
+        qDebug() << "RenameJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for renaming";
     return false;
 }
 
 bool ArchiveManager::batchExtractFiles(const QStringList &listFiles, const QString &strTargetPath/*, bool bAutoCreatDir*/)
 {
+    qDebug() << "Starting batchExtractFiles operation for" << listFiles.size() << "files";
     BatchExtractJob *pBatchExtractJob = new BatchExtractJob();
     pBatchExtractJob->setExtractPath(strTargetPath/*, bAutoCreatDir*/);
 
     if (pBatchExtractJob->setArchiveFiles(listFiles)) {
+        qDebug() << "Archive files set successfully for batch extraction";
         // 连接槽函数
         connect(pBatchExtractJob, &BatchExtractJob::signalJobFinshed, this, &ArchiveManager::slotJobFinished);
         connect(pBatchExtractJob, &BatchExtractJob::signalprogress, this, &ArchiveManager::signalprogress);
@@ -313,15 +348,18 @@ bool ArchiveManager::batchExtractFiles(const QStringList &listFiles, const QStri
         m_pArchiveJob = pBatchExtractJob;
         pBatchExtractJob->start();
 
+        qDebug() << "BatchExtractJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to set archive files for batch extraction";
     SAFE_DELETE_ELE(pBatchExtractJob);
     return false;
 }
 
 bool ArchiveManager::openFile(const QString &strArchiveFullPath, const FileEntry &stEntry, const QString &strTempExtractPath, const QString &strProgram)
 {
+    qDebug() << "Starting openFile operation for archive:" << strArchiveFullPath;
     QJsonObject obj{
         {"tid", EventLogUtils::OpenCompressFile},
         {"operate", "OpenCompressFile"},
@@ -329,10 +367,12 @@ bool ArchiveManager::openFile(const QString &strArchiveFullPath, const FileEntry
     };
     EventLogUtils::get().writeLogs(obj);
     if (nullptr == m_pInterface) {
+        qDebug() << "Creating interface for opening file";
         m_pInterface = UiTools::createInterface(strArchiveFullPath);
     }
 
     if (m_pInterface) {
+        qDebug() << "Creating OpenJob";
         OpenJob *pOpenJob = new OpenJob(stEntry, strTempExtractPath, strProgram, m_pInterface);
 
         // 连接槽函数
@@ -343,15 +383,19 @@ bool ArchiveManager::openFile(const QString &strArchiveFullPath, const FileEntry
         m_pArchiveJob = pOpenJob;
         pOpenJob->start();
 
+        qDebug() << "OpenJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for opening file";
     return false;
 }
 
 bool ArchiveManager::updateArchiveCacheData(const UpdateOptions &stOptions)
 {
+    qDebug() << "Starting updateArchiveCacheData operation";
     if (m_pInterface) {
+        qDebug() << "Creating UpdateJob";
         UpdateJob *pUpdateJob = new UpdateJob(stOptions, m_pInterface);
 
         // 连接槽函数
@@ -360,17 +404,21 @@ bool ArchiveManager::updateArchiveCacheData(const UpdateOptions &stOptions)
         m_pArchiveJob = pUpdateJob;
         pUpdateJob->start();
 
+        qDebug() << "UpdateJob started successfully";
         return true;
     }
 
+    qWarning() << "No interface available for updating archive cache data";
     return false;
 }
 
 bool ArchiveManager::updateArchiveComment(const QString &strArchiveFullPath, const QString &strComment)
 {
+    qDebug() << "Starting updateArchiveComment operation for archive:" << strArchiveFullPath;
     ReadOnlyArchiveInterface *pInterface = UiTools::createInterface(strArchiveFullPath, true, UiTools::APT_Libzip); // zip添加注释使用libzipplugin
 
     if (pInterface) {
+        qDebug() << "Creating CommentJob";
         CommentJob *pCommentJob = new CommentJob(strComment, pInterface);
 
         // 连接槽函数
@@ -380,14 +428,17 @@ bool ArchiveManager::updateArchiveComment(const QString &strArchiveFullPath, con
         m_pArchiveJob = pCommentJob;
         pCommentJob->start();
 
+        qDebug() << "CommentJob started successfully";
         return true;
     }
 
+    qWarning() << "Failed to create interface for updating archive comment";
     return false;
 }
 
 bool ArchiveManager::convertArchive(const QString &strOriginalArchiveFullPath, const QString &strTargetFullPath, const QString &strNewArchiveFullPath)
 {
+    qDebug() << "Starting convertArchive operation from:" << strOriginalArchiveFullPath << "to:" << strNewArchiveFullPath;
     ConvertJob *pConvertJob = new ConvertJob(strOriginalArchiveFullPath, strTargetFullPath, strNewArchiveFullPath);
     m_pArchiveJob = pConvertJob;
 
@@ -398,37 +449,46 @@ bool ArchiveManager::convertArchive(const QString &strOriginalArchiveFullPath, c
     connect(pConvertJob, &ConvertJob::signalQuery, this, &ArchiveManager::signalQuery);
 
     pConvertJob->start();
+    qDebug() << "ConvertJob started successfully";
     return true;
 }
 
 bool ArchiveManager::pauseOperation()
 {
+    qDebug() << "Attempting to pause current operation";
     // 调用job暂停接口
     if (m_pArchiveJob) {
+        qDebug() << "Pausing archive job";
         m_pArchiveJob->doPause();
 
         return true;
     }
 
+    qWarning() << "No archive job available to pause";
     return false;
 }
 
 bool ArchiveManager::continueOperation()
 {
+    qDebug() << "Attempting to continue current operation";
     // 调用job继续接口
     if (m_pArchiveJob) {
+        qDebug() << "Continuing archive job";
         m_pArchiveJob->doContinue();
 
         return true;
     }
 
+    qWarning() << "No archive job available to continue";
     return false;
 }
 
 bool ArchiveManager::cancelOperation()
 {
+    qDebug() << "Attempting to cancel current operation";
     // 调用job取消接口
     if (m_pArchiveJob) {
+        qDebug() << "Canceling archive job";
         m_pArchiveJob->kill();
         m_pArchiveJob->deleteLater();
         m_pArchiveJob = nullptr;
@@ -436,30 +496,36 @@ bool ArchiveManager::cancelOperation()
         return true;
     }
 
+    qWarning() << "No archive job available to cancel";
     return false;
 }
 
 QString ArchiveManager::getCurFilePassword()
 {
+    qDebug() << "Getting current file password";
     if (m_pInterface) {
         return m_pInterface->getPassword();
     }
 
+    qWarning() << "No interface available to get password";
     return "";
 }
 
 bool ArchiveManager::currentStatus()
 {
+    qDebug() << "Getting current operation status";
     // 调用job状态接口
     if (m_pArchiveJob) {
         return m_pArchiveJob->status();
     }
 
+    qWarning() << "No archive job available to get status";
     return false;
 }
 
 void ArchiveManager::slotJobFinished()
 {
+    qDebug() << "slotJobFinished called";
     if (m_pArchiveJob) {
         // 获取结束结果
         ArchiveJob::JobType eJobType = m_pArchiveJob->m_eJobType;
