@@ -24,23 +24,30 @@ DGUI_USE_NAMESPACE
 CompressPage::CompressPage(QWidget *parent)
     : DWidget(parent)
 {
+    qDebug() << "CompressPage constructor called";
     initUI();
     initConnections();
+    qDebug() << "CompressPage initialization completed";
 }
 
 CompressPage::~CompressPage()
 {
-
+    qDebug() << "CompressPage destructor called";
 }
 
 void CompressPage::addCompressFiles(const QStringList &listFiles)
 {
+    qDebug() << "Adding compress files, count:" << listFiles.size();
     m_pCompressView->addCompressFiles(listFiles);
+    qDebug() << "Compress files added successfully";
 }
 
 QStringList CompressPage::compressFiles()
 {
-    return m_pCompressView->getCompressFiles();
+    qDebug() << "Getting compress files list";
+    QStringList files = m_pCompressView->getCompressFiles();
+    qDebug() << "Current compress files count:" << files.size();
+    return files;
 }
 
 QList<FileEntry> CompressPage::getEntrys()
@@ -50,16 +57,21 @@ QList<FileEntry> CompressPage::getEntrys()
 
 void CompressPage::refreshCompressedFiles(bool bChanged, const QString &strFileName)
 {
+    qInfo() << "Refreshing compressed files, changed:" << bChanged << "file:" << strFileName;
     m_pCompressView->refreshCompressedFiles(bChanged, strFileName);
+    qInfo() << "Compressed files refreshed";
 }
 
 void CompressPage::clear()
 {
+    qDebug() << "Clearing compress page";
     m_pCompressView->clear();
+    qDebug() << "Compress page cleared";
 }
 
 void CompressPage::initUI()
 {
+    qInfo() << "Initializing compress page UI";
     // 初始化相关变量
     m_pCompressView = new CompressView(this);
     m_pNextBtn = new CustomPushButton(tr("Next"), this);
@@ -92,6 +104,7 @@ void CompressPage::initUI()
 
 void CompressPage::initConnections()
 {
+    qInfo() << "Initializing compress page connections";
     connect(m_pNextBtn, &DPushButton::clicked, this, &CompressPage::slotCompressNextClicked);
     connect(m_pCompressView, &CompressView::signalLevelChanged, this, &CompressPage::slotCompressLevelChanged);
 }
@@ -102,33 +115,41 @@ void CompressPage::slotCompressNextClicked()
 
     // 如果没有待压缩文件，弹出提示框
     if (m_pCompressView->getCompressFiles().isEmpty()) {
+        qInfo() << "No files to compress, showing tip dialog";
         TipDialog dialog(this);
         dialog.showDialog(tr("Please add files"), tr("OK", "button"));
     } else {
+        qInfo() << "Files to compress, emit signalCompressNextClicked";
         emit signalCompressNextClicked();  // 发送下一步信号
     }
 }
 
 void CompressPage::slotCompressLevelChanged(bool bRootIndex)
 {
+    qInfo() << "Compress level changed, root index:" << bRootIndex;
     m_bRootIndex = bRootIndex;
     emit signalLevelChanged(bRootIndex);
-
     setAcceptDrops(bRootIndex);
+    qInfo() << "Compress level change processed";
 }
 
 void CompressPage::slotFileChoose()
 {
-    if (m_bRootIndex)
+    qDebug() << "File choose requested, root index:" << m_bRootIndex;
+    if (m_bRootIndex) {
+        qDebug() << "Emitting file choose signal";
         emit signalFileChoose();
+    }
 }
 
 CustomPushButton *CompressPage::getNextBtn() const
 {
+    // qInfo() << "Getting next button pointer";
     return m_pNextBtn;
 }
 
 CompressView *CompressPage::getCompressView()
 {
+    // qInfo() << "Getting compress view pointer";
     return m_pCompressView;
 }
