@@ -83,11 +83,13 @@ void ProgressPage::setArchiveName(const QString &strArchiveName)
 
 QString ProgressPage::archiveName()
 {
+    // qDebug() << "Getting archive name:" << m_strArchiveName;
     return m_strArchiveName;
 }
 
 void ProgressPage::setProgress(double dPercent)
 {
+    // qDebug() << "Setting progress:" << dPercent << "%";
     // 添加对异常进度的判断处理
     if (dPercent > 100) {
         qWarning() << "Invalid progress percentage:" << dPercent;
@@ -117,6 +119,7 @@ void ProgressPage::setProgress(double dPercent)
 
 void ProgressPage::setCurrentFileName(const QString &strFileName)
 {
+    qInfo() << "Setting current file name:" << strFileName;
     QFontMetrics elideFont(m_pFileNameLbl->font());
 
     if (PT_Compress == m_eType || PT_CompressAdd == m_eType) {   // 压缩和追加压缩
@@ -136,6 +139,7 @@ void ProgressPage::setCurrentFileName(const QString &strFileName)
 
 void ProgressPage::resetProgress()
 {
+    qDebug() << "resetProgress";
     // 修复取消按键默认有焦点效果
     m_pCancelBtn->clearFocus();
     m_pPauseContinueButton->clearFocus();
@@ -159,22 +163,26 @@ void ProgressPage::resetProgress()
 
 void ProgressPage::restartTimer()
 {
+    qDebug() << "restartTimer";
     m_timer.restart();
 }
 
 void ProgressPage::setPushButtonCheckable(bool a, bool b)
 {
+    qDebug() << "setPushButtonCheckable, cancel:" << a << "pause/continue:" << b;
     m_pCancelBtn->setEnabled(a); // 取消按钮
     m_pPauseContinueButton->setEnabled(b); // 暂停继续按钮
 }
 
 bool ProgressPage::isPause()
 {
+    qDebug() << "isPause";
     return m_pPauseContinueButton->text() == tr("Continue", "button");
 }
 
 void ProgressPage::initUI()
 {
+    qDebug() << "initUI";
     // 初始化控件
     m_pPixmapLbl = new DLabel(this);
     m_pArchiveNameLbl = new DLabel(this);
@@ -262,13 +270,16 @@ void ProgressPage::initConnections()
 
 void ProgressPage::calSpeedAndRemainingTime(double &dSpeed, qint64 &qRemainingTime)
 {
+    qDebug() << "calSpeedAndRemainingTime";
     if (m_qConsumeTime < 0) {
+        qDebug() << "Consume time is negative, restart timer";
         m_timer.start();
     }
 
     m_qConsumeTime += m_timer.elapsed();
 
     if (m_qConsumeTime < 0) {
+        qWarning() << "Consume time is negative, reset speed and remaining time";
         dSpeed = 0.0;
         qRemainingTime = 0;
         return;
@@ -276,11 +287,14 @@ void ProgressPage::calSpeedAndRemainingTime(double &dSpeed, qint64 &qRemainingTi
 
     // 计算速度
     if (0 == m_qConsumeTime) {
+        qWarning() << "Consume time is zero, set speed to 0";
         dSpeed = 0.0; //处理速度
     } else {
         if (PT_Convert == m_eType) {
+            qDebug() << "Calculate speed for convert type";
             dSpeed = 2 * (m_qTotalSize / 1024.0 * m_iPerent / 100) / m_qConsumeTime * 1000;
         } else {
+            qDebug() << "Calculate speed for other types";
             dSpeed = (m_qTotalSize / 1024.0 * m_iPerent / 100) / m_qConsumeTime * 1000;
         }
     }
@@ -288,22 +302,27 @@ void ProgressPage::calSpeedAndRemainingTime(double &dSpeed, qint64 &qRemainingTi
     // 计算剩余时间
     double sizeLeft = 0;
     if (PT_Convert == m_eType) {
+        qDebug() << "Calculate remaining size for convert type";
         sizeLeft = (m_qTotalSize * 2 / 1024.0) * (100 - m_iPerent) / 100; //剩余大小
     } else {
+        qDebug() << "Calculate remaining size for other types";
         sizeLeft = (m_qTotalSize / 1024.0) * (100 - m_iPerent) / 100; //剩余大小
     }
 
     if (dSpeed != 0.0) {
+        qDebug() << "Calculate remaining time";
         qRemainingTime = qint64(sizeLeft / dSpeed); //剩余时间
     }
 
     if (100 != qRemainingTime && 0 == qRemainingTime) {
+        qDebug() << "Remaining time is 0, set to 1";
         qRemainingTime = 1;
     }
 }
 
 void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
 {
+    qDebug() << "displaySpeedAndTime";
     // 计算剩余需要的小时。
     qint64 hour = qRemainingTime / 3600;
     // 计算剩余的分钟
@@ -319,6 +338,7 @@ void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
     // 设置剩余时间
     m_pRemainingTimeLbl->setText(tr("Time left") + ": " + hh + ":" + mm + ":" + ss);
     if (PT_Compress == m_eType || PT_CompressAdd == m_eType) {
+        qInfo() << "operation type: compress";
         if (dSpeed < 1024) {
             // 速度小于1024k， 显示速度单位为KB/s
             m_pSpeedLbl->setText(tr("Speed", "compress") + ": " + QString::number(dSpeed, 'f', 2) + "KB/s");
@@ -330,18 +350,21 @@ void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
             m_pSpeedLbl->setText(tr("Speed", "compress") + ": " + ">300MB/s");
         }
     } else if (PT_Delete == m_eType) {
+        qInfo() << "operation type: delete";
         if (dSpeed < 1024) {
             m_pSpeedLbl->setText(tr("Speed", "delete") + ": " + QString::number(dSpeed, 'f', 2) + "KB/s");
         } else {
             m_pSpeedLbl->setText(tr("Speed", "delete") + ": " + QString::number((dSpeed / 1024), 'f', 2) + "MB/s");
         }
     } else if (PT_Rename == m_eType) {
+        qInfo() << "operation type: rename";
         if (dSpeed < 1024) {
             m_pSpeedLbl->setText(tr("Speed", "rename") + ": " + QString::number(dSpeed, 'f', 2) + "KB/s");
         } else {
             m_pSpeedLbl->setText(tr("Speed", "rename") + ": " + QString::number((dSpeed / 1024), 'f', 2) + "MB/s");
         }
     } else if (PT_UnCompress == m_eType) {
+        qInfo() << "operation type: uncompress";
         if (dSpeed < 1024) {
             m_pSpeedLbl->setText(tr("Speed", "uncompress") + ": " + QString::number(dSpeed, 'f', 2) + "KB/s");
         } else if (dSpeed > 1024 && dSpeed < 1024 * 300) {
@@ -350,6 +373,7 @@ void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
             m_pSpeedLbl->setText(tr("Speed", "uncompress") + ": " + ">300MB/s");
         }
     } else if (PT_Convert == m_eType) {
+        qInfo() << "operation type: convert";
         if (dSpeed < 1024) {
             m_pSpeedLbl->setText(tr("Speed", "convert") + ": " + QString::number(dSpeed, 'f', 2) + "KB/s");
         } else if (dSpeed > 1024 && dSpeed < 1024 * 300) {
@@ -358,6 +382,7 @@ void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
             m_pSpeedLbl->setText(tr("Speed", "convert") + ": " + ">300MB/s");
         }
     } else if (PT_Comment == m_eType) {
+        qInfo() << "operation type: comment";
         m_pSpeedLbl->setText("");
         m_pRemainingTimeLbl->setText("");
     }
@@ -365,6 +390,7 @@ void ProgressPage::displaySpeedAndTime(double dSpeed, qint64 qRemainingTime)
 
 void ProgressPage::slotPauseClicked(bool bChecked)
 {
+    qInfo() << "Pause/continue button clicked, checked:" << bChecked;
     if (bChecked) {
         // 暂停操作
         qInfo() << "Pause operation requested";
@@ -391,14 +417,19 @@ void ProgressPage::slotCancelClicked()
     // 对话框文字描述
     QString strDesText;
     if (PT_Compress == m_eType) {
+        qInfo() << "operation type: compress";
         strDesText = tr("Are you sure you want to stop the compression?");      // 是否停止压缩
     } else if (PT_UnCompress == m_eType) {
+        qInfo() << "operation type: uncompress";
         strDesText = tr("Are you sure you want to stop the decompression?");      // 是否停止解压
     } else if (PT_Delete == m_eType) {
+        qInfo() << "operation type: delete";
         strDesText = tr("Are you sure you want to stop the deletion?");      // 是否停止删除
     } else if (PT_CompressAdd == m_eType) {
+        qInfo() << "operation type: compress add";
         strDesText = tr("Are you sure you want to stop the compression?");      // 是否停止追加
     } else if (PT_Convert == m_eType) {
+        qInfo() << "operation type: convert";
         strDesText = tr("Are you sure you want to stop the conversion?");      // 是否停止转换
     }
 
@@ -413,6 +444,7 @@ void ProgressPage::slotCancelClicked()
         // 恢复原来状态
         qInfo() << "User canceled the cancel operation";
         if (!CheckedFlag) { // 原来是运行状态
+            qDebug() << "Resuming operation after cancel";
             emit m_pPauseContinueButton->clicked(false);
         }
     }
